%define staticdevelname %mklibname bison -d -s

%bcond_without check

Summary:	A GNU general-purpose parser generator
Name:		bison
Version:	3.8.2
Release:	%mkrel 5
License:	GPLv3+
Group:		Development/Tools
URL:		https://www.gnu.org/software/bison/bison.html
Source0:	https://ftp.gnu.org/gnu/bison/bison-%{version}.tar.xz
Patch0:		bison-1.32-extfix.patch
BuildRequires:	gettext-devel >= 0.20.2-4
BuildRequires:	help2man
BuildRequires:	m4 >= 1.4
#for tests
BuildRequires:	flex
Requires:	m4 >= 1.4

%description
Bison is a general purpose parser generator which converts a grammar
description for an LALR context-free grammar into a C program to parse
that grammar.  Bison can be used to develop a wide range of language
parsers, from ones used in simple desk calculators to complex programming
languages.  Bison is upwardly compatible with Yacc, so any correctly
written Yacc grammar should work with Bison without any changes.  If
you know Yacc, you shouldn't have any trouble using Bison (but you do need
to be very proficient in C programming to be able to use Bison).  Many
programs use Bison as part of their build process. Bison is only needed
on systems that are used for development.

If your system will be used for C development, you should install Bison
since it is used to build many C programs.

%package -n	%{staticdevelname}
Summary:	Static development library for using Bison-generated parsers
Group:		Development/C
Requires:	bison = %{version}
Provides:	bison-devel-static = %{version}

%description -n	%{staticdevelname}
This package contains the static -ly library sometimes used by programs using
Bison-generated parsers. If you are developing programs using Bison, you might
want to link with this library. This library is not required by all
Bison-generated parsers, but may be employed by simple programs to supply
minimal support for the generated parsers.

%prep
%autosetup -p1

#fix build with autoreconf
sed -i -e 's,AM_GNU_GETTEXT_VERSION,AM_GNU_GETTEXT_REQUIRE_VERSION,' configure.ac

%build
autoreconf -fi
%configure
%make_build

%if %{with check}
%check
make check
%endif

%install
%make_install

mv %{buildroot}%{_bindir}/yacc %{buildroot}%{_bindir}/yacc.bison

%find_lang %{name} --all-name

%post
%{_sbindir}/update-alternatives --install %{_bindir}/yacc yacc %{_bindir}/yacc.bison 10

%preun
if [ $1 -eq 0 ]; then
  %{_sbindir}/update-alternatives --remove yacc %{_bindir}/yacc.bison
fi

%files -f %{name}.lang
%doc AUTHORS COPYING NEWS README THANKS TODO
%{_bindir}/*
%dir %{_datadir}/bison
%{_datadir}/bison/*
%{_datadir}/aclocal/*
%{_infodir}/bison.info*
%{_mandir}/man1/*
%{_docdir}/bison/examples

%files -n %{staticdevelname}
%{_libdir}/liby.a


%changelog
* Sat Jun 28 2025 umeabot <umeabot> 3.8.2-5.mga10
+ Revision: 2217822
- Mageia 10 Mass Rebuild

* Sun Feb 12 2023 ghibo <ghibo> 3.8.2-4.mga9
+ Revision: 1941104
- Rebuild for aging

* Wed Apr 06 2022 wally <wally> 3.8.2-3.mga9
+ Revision: 1846543
- rebuild for gettext without libtextstyle

* Thu Mar 17 2022 umeabot <umeabot> 3.8.2-2.mga9
+ Revision: 1797012
- Mageia 9 Mass Rebuild

* Sat Sep 25 2021 kekepower <kekepower> 3.8.2-1.mga9
+ Revision: 1746391
- Update to version 3.8.2

* Sun Sep 12 2021 kekepower <kekepower> 3.8.1-1.mga9
+ Revision: 1745253
- Update to version 3.8.1

* Wed Sep 08 2021 luigiwalser <luigiwalser> 3.8-1.mga9
+ Revision: 1744544
- 3.8
- remove no longer needed patch

* Fri Mar 12 2021 kekepower <kekepower> 3.7.6-1.mga9
+ Revision: 1701758
- Update to version 3.7.6

* Sun Jan 24 2021 luigiwalser <luigiwalser> 3.7.5-1.mga8
+ Revision: 1673214
- 3.7.5

* Sat Dec 12 2020 wally <wally> 3.7.4-2.mga8
+ Revision: 1655802
- fix build with autoconf 2.70

* Sat Nov 14 2020 kekepower <kekepower> 3.7.4-1.mga8
+ Revision: 1646164
- Update to version 3.7.4

* Tue Oct 13 2020 kekepower <kekepower> 3.7.3-1.mga8
+ Revision: 1635307
- Update to version 3.7.3

* Sun Sep 06 2020 luigiwalser <luigiwalser> 3.7.2-1.mga8
+ Revision: 1622893
- remove java BR and bootstrap stuff
- 3.7.2

* Sun Aug 02 2020 kekepower <kekepower> 3.7.1-1.mga8
+ Revision: 1610632
- Update to version 3.7.1

* Sun Jul 26 2020 wally <wally> 3.7-2.mga8
+ Revision: 1609101
- bump gettext BR

* Thu Jul 23 2020 luigiwalser <luigiwalser> 3.7-1.mga8
+ Revision: 1608597
- 3.7

* Wed Jun 17 2020 kekepower <kekepower> 3.6.4-1.mga8
+ Revision: 1594065
- Update to version 3.6.4

* Wed Jun 03 2020 kekepower <kekepower> 3.6.3-1.mga8
+ Revision: 1590051
- Update to version 3.6.3

* Mon May 18 2020 daviddavid <daviddavid> 3.6.2-1.mga8
+ Revision: 1585990
- new version: 3.6.2

* Mon May 11 2020 daviddavid <daviddavid> 3.6.1-1.mga8
+ Revision: 1582859
- new version: 3.6.1

* Sun May 10 2020 daviddavid <daviddavid> 3.6-1.mga8
+ Revision: 1582506
- new version: 3.6

* Sun Apr 05 2020 luigiwalser <luigiwalser> 3.5.4-1.mga8
+ Revision: 1564964
- 3.5.4

* Sun Mar 08 2020 kekepower <kekepower> 3.5.3-1.mga8
+ Revision: 1554975
- Update to version 3.5.3

* Wed Feb 19 2020 umeabot <umeabot> 3.5.2-2.mga8
+ Revision: 1543468
- Mageia 8 Mass Rebuild

* Thu Feb 13 2020 luigiwalser <luigiwalser> 3.5.2-1.mga8
+ Revision: 1514801
- 3.5.2

* Mon Jan 20 2020 kekepower <kekepower> 3.5.1-1.mga8
+ Revision: 1481743
- Update to version 3.5.1
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Dec 13 2019 kekepower <kekepower> 3.5-1.mga8
+ Revision: 1466152
- Update to version 3.5

* Fri Sep 13 2019 daviddavid <daviddavid> 3.4.2-1.mga8
+ Revision: 1440139
- new version: 3.4.2

* Sun Jun 30 2019 daviddavid <daviddavid> 3.4.1-1.mga8
+ Revision: 1416499
- new version: 3.4.1

* Sun Feb 03 2019 luigiwalser <luigiwalser> 3.3.2-1.mga7
+ Revision: 1362929
- 3.3.2

* Sat Feb 02 2019 tmb <tmb> 3.3.1-1.mga7
+ Revision: 1362332
- update to 3.3.1

* Sat Jan 26 2019 kekepower <kekepower> 3.3-1.mga7
+ Revision: 1361167
- Update to version 3.3

* Mon Dec 24 2018 kekepower <kekepower> 3.2.4-1.mga7
+ Revision: 1344858
- Update to version 3.2.4

* Wed Dec 19 2018 kekepower <kekepower> 3.2.3-1.mga7
+ Revision: 1342826
- Update to version 3.2.3

* Thu Nov 22 2018 kekepower <kekepower> 3.2.2-1.mga7
+ Revision: 1333402
- Try again without disabling tests
- Disable tests number 331, 341 and 460 for now
- Update to version 3.2.2

* Fri Nov 09 2018 daviddavid <daviddavid> 3.2.1-1.mga7
+ Revision: 1329124
- new version: 3.2.1

* Wed Oct 31 2018 daviddavid <daviddavid> 3.2-1.mga7
+ Revision: 1326860
- new version: 3.2

* Fri Sep 21 2018 umeabot <umeabot> 3.1-3.mga7
+ Revision: 1295447
- Mageia 7 Mass Rebuild

* Mon Sep 03 2018 tv <tv> 3.1-2.mga7
+ Revision: 1256425
- rely on filetriggers for info system (mga#23482)
- rely on filetriggers for info system (mga#23482)

* Tue Aug 28 2018 daviddavid <daviddavid> 3.1-1.mga7
+ Revision: 1255357
- new version: 3.1

* Thu May 31 2018 kekepower <kekepower> 3.0.5-1.mga7
+ Revision: 1233199
- Update to version 3.0.5

* Sun Sep 24 2017 cjw <cjw> 3.0.4-4.mga7
+ Revision: 1158687
- add buildrequires: gettext-devel
- add upstream fix for test failures with gcc 7

* Sat Feb 13 2016 umeabot <umeabot> 3.0.4-3.mga6
+ Revision: 959591
- Mageia 6 Mass Rebuild

* Thu Oct 15 2015 shlomif <shlomif> 3.0.4-2.mga6
+ Revision: 891768
- Include missing files under docdir.

* Tue Jan 27 2015 luigiwalser <luigiwalser> 3.0.4-1.mga5
+ Revision: 812468
- 3.0.4

* Thu Jan 15 2015 luigiwalser <luigiwalser> 3.0.3-1.mga5
+ Revision: 810774
- 3.0.3

* Wed Oct 15 2014 umeabot <umeabot> 3.0.2-3.mga5
+ Revision: 739035
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.0.2-2.mga5
+ Revision: 678160
- Mageia 5 Mass Rebuild

* Thu Dec 05 2013 luigiwalser <luigiwalser> 3.0.2-1.mga4
+ Revision: 555410
- 3.0.2

* Sat Oct 19 2013 umeabot <umeabot> 3.0-2.mga4
+ Revision: 533508
- Mageia 4 Mass Rebuild

* Sat Aug 31 2013 wally <wally> 3.0-1.mga4
+ Revision: 473700
- BR flex for tests
+ fwang <fwang>
- new version 3.0

* Fri May 24 2013 luigiwalser <luigiwalser> 2.7.1-1.mga4
+ Revision: 426594
- 2.7.1

* Fri Jan 11 2013 umeabot <umeabot> 2.7-2.mga3
+ Revision: 346908
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 15 2012 luigiwalser <luigiwalser> 2.7-1.mga3
+ Revision: 331235
- 2.7

* Thu Nov 08 2012 fwang <fwang> 2.6.5-1.mga3
+ Revision: 316291
- new version 2.6.5
- cleanup spec and rpm group

* Wed Oct 24 2012 fwang <fwang> 2.6.4-1.mga3
+ Revision: 309592
- new version 2.6.4

* Tue Oct 23 2012 fwang <fwang> 2.6.3-1.mga3
+ Revision: 309399
- new version 2.6.3

* Fri Aug 03 2012 fwang <fwang> 2.6.2-1.mga3
+ Revision: 278293
- new version 2.6.2

* Wed Aug 01 2012 fwang <fwang> 2.6.1-1.mga3
+ Revision: 277151
- new version 2.6.1

* Fri Jul 20 2012 fwang <fwang> 2.6-1.mga3
+ Revision: 272741
- new version 2.6

* Wed Jun 06 2012 fwang <fwang> 2.5.1-1.mga3
+ Revision: 256088
- new version 2.5.1

* Fri Jun 17 2011 tv <tv> 2.5-1.mga2
+ Revision: 109238
- new release

* Sun Jan 09 2011 blino <blino> 2.4.3-2.mga1
+ Revision: 2170
- rebuild  with java

* Sat Jan 08 2011 blino <blino> 2.4.3-1.mga1
+ Revision: 404
- bootstrap bison
- add bootstrap flag
- remove obsolete stuff
- imported package bison


* Fri Aug 06 2010 Funda Wang <fwang@mandriva.org> 2.4.3-1mdv2011.0
+ Revision: 567145
- New version 2.4.3

* Sun Mar 21 2010 Funda Wang <fwang@mandriva.org> 2.4.2-1mdv2010.1
+ Revision: 525959
- output test do not need any more
- subpipe patch do not apply
- new version 2.4.2

* Sun Mar 14 2010 Oden Eriksson <oeriksson@mandriva.com> 2.4.1-5mdv2010.1
+ Revision: 518986
- rebuild

* Sun Oct 04 2009 Oden Eriksson <oeriksson@mandriva.com> 2.4.1-4mdv2010.0
+ Revision: 453330
- package the static lib (requested by mnaud)

* Fri Sep 25 2009 Olivier Blin <oblin@mandriva.com> 2.4.1-3mdv2010.0
+ Revision: 448805
- disable java on mips & arm (from Arnaud Patard)

* Sun Aug 09 2009 Oden Eriksson <oeriksson@mandriva.com> 2.4.1-2mdv2010.0
+ Revision: 413170
- rebuild

* Tue Dec 30 2008 Oden Eriksson <oeriksson@mandriva.com> 2.4.1-1mdv2009.1
+ Revision: 321329
- 2.4.1
- sync with fedora (P2 + deps)
- fix build with -Wformat-security (P3)

* Sat Nov 29 2008 Christiaan Welvaart <spturtle@mandriva.org> 2.4-1mdv2009.1
+ Revision: 308164
- 2.4
- rediff patch0
- patch1: disable test for not overwriting input file
- add buildrequires: help2man

* Mon Jun 16 2008 Thierry Vignaud <tv@mandriva.org> 2.3-6mdv2009.0
+ Revision: 220482
- rebuild

* Sun Jan 06 2008 Stefan van der Eijk <stefan@mandriva.org> 2.3-5mdv2008.1
+ Revision: 146027
- rebuild to fix error: unpacking of archive failed on file /usr/bin/bison;4780a23e: cpio: read

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request


* Mon Mar 19 2007 Thierry Vignaud <tvignaud@mandriva.com> 2.3-4mdv2007.1
+ Revision: 146590
- do not package big ChangeLog

* Sat Jan 13 2007 Götz Waschk <waschk@mandriva.org> 2.3-3mdv2007.1
+ Revision: 108197
- fix pre and preun requires
- use check macro
- use find-lang

  + Oden Eriksson <oeriksson@mandriva.com>
    - bzip2 cleanup

* Wed Oct 11 2006 Oden Eriksson <oeriksson@mandriva.com> 2.3-2mdv2007.1
+ Revision: 63270
- bunzip patches
- Import bison

* Fri Jul 21 2006 Emmanuel Andry <eandry@mandriva.org> 2.3-1mdv2007.0
- 2.3

* Sat Jun 03 2006 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 2.2-1mdv2007.0
- 2.2

* Tue May 16 2006 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 2.1-3mdk
- Rebuild (missing binary)

* Sat May 13 2006 Stefan van der Eijk <stefan@eijk.nu> 2.1-2mdk
- rebuild for sparc

* Thu Oct 06 2005 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 2.1-1mdk
- New version

* Fri Aug 12 2005 Nicolas Lécureuil <neoclust@mandriva.org> 2.0-3mdk
- fix rpmlint errors (PreReq)

* Fri Aug 12 2005 Nicolas Lécureuil <neoclust@mandriva.org> 2.0-2mdk
- fix rpmlint errors (PreReq)

* Wed Jan 05 2005 Rafael Garcia-Suarez <rgarciasuarez@mandrakesoft.com> 2.0-1mdk
- New version
- Add docs

* Thu Dec 23 2004 Abel Cheung <deaddog@mandrake.org> 1.875e-1mdk
- New version
- Fix URL
- Make it an alternative to byacc
- make check

* Fri Jul 30 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.875d-1mdk
- 1.875d
- drop P1 (fixed upstream)
- cosmetics

* Wed Jun 02 2004 Robert Vojta <robert.vojta@mandrake.org> 1.875-5mdk
- Requires m4 package (#9922)

